@@ -14,8 +14,8 @@ package Net::BitTorrent::Session::File;
     #    qw[splitpath catpath];
     #
     use version qw[qv];                     # core as of 5.009
-    our $SVN = q[$Id: BitTorrent.pm 27 2008-09-24 00:35:26Z sanko@cpan.org $];
-    our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new((qw$Rev: 27 $)[1])->numify / 1000), $UNSTABLE_RELEASE);
+    our $SVN = q[$Id: File.pm 28 2008-09-26 22:47:04Z sanko@cpan.org $];
+    our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new((qw$Rev: 28 $)[1])->numify / 1000), $UNSTABLE_RELEASE);
 
     #
     my (%path,     %session, %size,   %index);          # parameters to new()
@@ -557,6 +557,12 @@ package Net::BitTorrent::Session::File;
         }
         return 1;
     }
+        sub _as_string {
+            my ($self, $advanced) = @_;
+            my $dump = q[TODO];
+            return print STDERR qq[$dump\n] unless defined wantarray;
+            return $dump;
+        }
 
     #
     DESTROY {
@@ -709,7 +715,7 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: File.pm 27 2008-09-24 00:35:26Z sanko@cpan.org $
+=for svn $Id: File.pm 28 2008-09-26 22:47:04Z sanko@cpan.org $
 
 =cut
 
